@@ -5,7 +5,7 @@ import os
 import sys
 
 
-VERSION = (0, 8, 1)
+VERSION = (0, 9, 0)
 
 __version__ = '.'.join((str(each) for each in VERSION[:4]))
 
@@ -19,21 +19,25 @@ def update_sys_path():
     dirpath = os.path.abspath(os.path.dirname(__file__))
     sys.path.insert(0, dirpath)
 
-def main():
+def get_manager():
     update_sys_path()
     from monolith.cli import ExecutionManager
     from porunga.utils.imports import import_class
 
-    class ForfiterManager(ExecutionManager):
+    class PorungaManager(ExecutionManager):
 
         def get_commands_to_register(self):
             registry = {
-                'test': 'porunga.commands.test.TestCommand',
+                'test': 'porunga.commands.test.PorungaTestCommand',
             }
             commands = dict((name, import_class(path)) for name, path in
                 registry.items())
             return commands
 
-    manager = ForfiterManager(['porunga'])
+    return PorungaManager(['porunga'])
+
+
+def main():
+    manager = get_manager()
     manager.execute()
 
